Struct frame_executive::Executive [−][src]
pub struct Executive<System, Block, Context, UnsignedValidator, AllPallets, OnRuntimeUpgrade = ()>(_);Expand description
Main entry point for certain runtime actions as e.g. execute_block.
Generic parameters:
System: Something that implementsframe_system::ConfigBlock: The block type of the runtimeContext: The context that is used when checking an extrinsic.UnsignedValidator: The unsigned transaction validator of the runtime.AllPallets: Tuple that contains all modules. Will be used to call e.g.on_initialize.OnRuntimeUpgrade: Custom logic that should be called after a runtime upgrade. Modules are already called byAllPallets. It will be called before all modules will be called.
Implementations
impl<System: Config + EnsureInherentsAreFirst<Block>, Block: Block<Header = System::Header, Hash = System::Hash>, Context: Default, UnsignedValidator, AllPallets: OnRuntimeUpgrade + OnInitialize<System::BlockNumber> + OnIdle<System::BlockNumber> + OnFinalize<System::BlockNumber> + OffchainWorker<System::BlockNumber>, COnRuntimeUpgrade: OnRuntimeUpgrade> Executive<System, Block, Context, UnsignedValidator, AllPallets, COnRuntimeUpgrade> where
Block::Extrinsic: Checkable<Context> + Codec,
CheckedOf<Block::Extrinsic, Context>: Applyable + GetDispatchInfo,
CallOf<Block::Extrinsic, Context>: Dispatchable<Info = DispatchInfo, PostInfo = PostDispatchInfo>,
OriginOf<Block::Extrinsic, Context>: From<Option<System::AccountId>>,
UnsignedValidator: ValidateUnsigned<Call = CallOf<Block::Extrinsic, Context>>,
impl<System: Config + EnsureInherentsAreFirst<Block>, Block: Block<Header = System::Header, Hash = System::Hash>, Context: Default, UnsignedValidator, AllPallets: OnRuntimeUpgrade + OnInitialize<System::BlockNumber> + OnIdle<System::BlockNumber> + OnFinalize<System::BlockNumber> + OffchainWorker<System::BlockNumber>, COnRuntimeUpgrade: OnRuntimeUpgrade> Executive<System, Block, Context, UnsignedValidator, AllPallets, COnRuntimeUpgrade> where
Block::Extrinsic: Checkable<Context> + Codec,
CheckedOf<Block::Extrinsic, Context>: Applyable + GetDispatchInfo,
CallOf<Block::Extrinsic, Context>: Dispatchable<Info = DispatchInfo, PostInfo = PostDispatchInfo>,
OriginOf<Block::Extrinsic, Context>: From<Option<System::AccountId>>,
UnsignedValidator: ValidateUnsigned<Call = CallOf<Block::Extrinsic, Context>>,
Execute all OnRuntimeUpgrade of this runtime, and return the aggregate weight.
Start the execution of a particular block.
Actually execute all transitions for block.
Finalize the block - it is up the caller to ensure that all header fields are valid except state-root.
Apply extrinsic outside of the block execution function.
This doesn’t attempt to validate anything regarding the block, but it builds a list of uxt hashes.
pub fn validate_transaction(
source: TransactionSource,
uxt: Block::Extrinsic,
block_hash: Block::Hash
) -> TransactionValidity
pub fn validate_transaction(
source: TransactionSource,
uxt: Block::Extrinsic,
block_hash: Block::Hash
) -> TransactionValidity
Check a given signed transaction for validity. This doesn’t execute any side-effects; it merely checks whether the transaction would panic if it were included or not.
Changes made to storage should be discarded.
Start an offchain worker and generate extrinsics.